@@ -475,8 +475,11 @@ print_pkenc_list( struct kidlist_item *list, int failed )
 	    }
 	}
 	else if (list->reason)
+          {
 	    log_info(_("public key decryption failed: %s\n"),
 						g10_errstr(list->reason));
+            write_status_error ("pkdecrypt_failed", list->reason);
+          }
     }
 }
 
@@ -586,6 +589,13 @@ proc_encrypted( CTX c, PACKET *pkt )
 	write_status( STATUS_DECRYPTION_FAILED );
     }
     else {
+        if (gpg_err_code (result) == GPG_ERR_BAD_KEY
+	    && *c->dek->s2k_cacheid != '\0')
+	  {
+	    log_debug(_("cleared passphrase cached with ID: %s\n"),
+		      c->dek->s2k_cacheid);
+	    passphrase_clear_cache (NULL, c->dek->s2k_cacheid, 0);
+	  }
 	write_status( STATUS_DECRYPTION_FAILED );
 	log_error(_("decryption failed: %s\n"), g10_errstr(result));
 	/* Hmmm: does this work when we have encrypted using multiple
